import java.util.*;

/**
 * Golf-Weitschlag-Wettbewerb.
 * 
 * @author Owyn
 * @version 2008-06-19
 */
public class Golf {
    
    /**
     * Datenstruktur, in der die Spieler mit ihren Schlagweiten verwaltet werden.
     */
    private Map players;
    
    /**
     * Erzeugt einen neuen Golf-Weitschlag-Wettbewerb.
     */
    Golf() {
        this(2);
    }
    
    /**
     * Erzeugt einen neuen Golf-Weitschlag-Wettbewerb.
     * 
     * @param typ Art der Datenspeicherung.
     *            0: HashMap,
     *            1: TreeMap,
     *            2: TreeMap mit GolfComparator,
     *            3: TreeMap mit DifferenceComparator (Bezugswert 100.0)
     */
    Golf(int typ) {
        switch (typ) {
            case 0: // Aufgabe 2: HashMap
                players = new HashMap();
                break;
            case 1: // Aufgabe 2: TreeMap und Sortierung nach natuerlicher Ordnung
                players = new TreeMap();
                break;
            case 3: // Aufgabe 3: TreeMap und Sortierung nach Bezugs-Schlagweite 100.0 m
                players = new TreeMap(new DifferenceComparator(100.0));
                break;
            default: // Aufgabe 2: TreeMap und absteigende Sortierung
                players = new TreeMap(new GolfComparator());
                break;
        }
    }
    
    /**
     * F&uuml;gt einen Spieler mit seiner Schlagweite hinzu.
     * 
     * @param name Name des Spielers
     * @param distance Schlagweite des Spielers
     */
    public void addPlayer(String name, double distance) {
        players.put(Double.valueOf(distance), name);
    }
    
    /**
     * Gibt die Liste aus
     */
    public void printList() {
        int pos = 1; // Platzierungsnummer initialisieren
        
        // Iteriere ueber sortierte Liste von Sprungergebnissen
        for (Iterator i = players.keySet().iterator(); i.hasNext(); pos++) {
            // Schlagweite einlesen
            Double distance = (Double) i.next();
            
            // Zugehoerigen Spielernamen holen
            String name = (String) players.get(distance);
            
            System.out.println("Platz " + pos + ": " + name + " - Schlagweite: " + distance);
        }
    }
    
    /**
     * Testet die Klasse Golf.
     */
    public static void test() {
        test(2);
    }
    
    /**
     * Testet die Klasse Golf.
     * 
     * @param typ Art der Datenspeicherung.
     *            0: HashMap,
     *            1: TreeMap,
     *            2: TreeMap mit GolfComparator,
     *            3: TreeMap mit DifferenceComparator (Bezugswert 100.0)
     */
    public static void test(int typ) {
        Golf golf = new Golf(typ);
        
        // Schlagweiten erfassen
        golf.addPlayer("Emil Einself", 111.11);
        golf.addPlayer("August Aufsteigend", 123.45);
        golf.addPlayer("Karl Koelsch", 47.11);
        golf.addPlayer("Albrecht Absteigend", 98.76);
        
        // Sortierte Liste ausgeben
        System.out.println(" Golf-Ergebnisliste ");
        System.out.println("--------------------");
        golf.printList();
    }

}
